@@ -102,15 +102,15 @@ def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	db.execQuery(sql, data)
 
 
-def _insert_jos_xprofiles(db, uid, fname, lname, username, email, joomlagid, joomlagidNumber, gid, gidNumber):
+def _insert_jos_xprofiles(db, hubname, uid, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber):
 	sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
 	sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
 	sql += "`mailPreferenceOption`, `usageAgreement`, `jobsAllowed`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
 	sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
 	sql += "VALUES (" + '%s,'*37 + "%s );" 
 	
-	data = (uid, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, '/home/username', '', 
-	        '', 'password', gid, 'public', '', '', '', '', '', '', 
+	data = (uid, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, '/home/' + hubname + "/" + username, '', 
+	        '', hubzero.config.passwords.MD5PasswordHash(pw), gid, 'public', '', '', '', '', '', '', 
 	        0, 0, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
 	        '', '', fname, '', lname, '', 0, 0, '', '', None)
 	db.execQuery(sql, data)
@@ -228,7 +228,7 @@ def addhubgroup(groupName):
 	_add_ldap_group(groupName, groupName, gidNumber)
 	
 	
-def addhubuser(username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, skipldap):
+def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, skipldap):
 	# grab config options
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -241,7 +241,7 @@ def addhubuser(username, fname, lname, email, pw, joomlagid, joomlagidNumber, gi
 	userID = _insert_jos_users(db, joomlauserid, fullname, username, email, pw, joomlagid, joomlagidNumber)
 	aroID = _insert_jos_core_acl_aro(db, userID, fullname)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
-	_insert_jos_xprofiles(db, userID, fname, lname, username, email, joomlagid, joomlagidNumber, gid, gidNumber)
+	_insert_jos_xprofiles(db, hubname, userID, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber)
 	_insert_jos_users_password(db, userID, pw)
 	
 	# TODO add password table entry
